
:orphan:

.. _sphx_glr_sg_execution_times:


Computation times
=================
**00:00.000** total execution time for 27 files **from all galleries**:

.. container::

  .. raw:: html

    <style scoped>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet" />
    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
    </style>
    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script type="text/javascript" class="init">
    $(document).ready( function () {
        $('table.sg-datatable').DataTable({order: [[1, 'desc']]});
    } );
    </script>

  .. list-table::
   :header-rows: 1
   :class: table table-striped sg-datatable

   * - Example
     - Time
     - Mem (MB)
   * - :ref:`sphx_glr_examples_advanced__json_parser.py` (``../examples/advanced/_json_parser.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_conf_earley.py` (``../examples/advanced/conf_earley.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_conf_lalr.py` (``../examples/advanced/conf_lalr.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_create_ast.py` (``../examples/advanced/create_ast.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_custom_lexer.py` (``../examples/advanced/custom_lexer.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_dynamic_complete.py` (``../examples/advanced/dynamic_complete.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_error_handling.py` (``../examples/advanced/error_handling.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_error_reporting_earley.py` (``../examples/advanced/error_reporting_earley.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_error_reporting_lalr.py` (``../examples/advanced/error_reporting_lalr.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_prioritizer.py` (``../examples/advanced/prioritizer.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_py3to2.py` (``../examples/advanced/py3to2.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_python_parser.py` (``../examples/advanced/python_parser.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_qscintilla_json.py` (``../examples/advanced/qscintilla_json.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_reconstruct_json.py` (``../examples/advanced/reconstruct_json.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_reconstruct_python.py` (``../examples/advanced/reconstruct_python.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_templates.py` (``../examples/advanced/templates.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_advanced_tree_forest_transformer.py` (``../examples/advanced/tree_forest_transformer.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_calc.py` (``../examples/calc.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_composition_eval_csv.py` (``../examples/composition/eval_csv.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_composition_eval_json.py` (``../examples/composition/eval_json.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_composition_main.py` (``../examples/composition/main.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_fruitflies.py` (``../examples/fruitflies.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_indented_tree.py` (``../examples/indented_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_json_parser.py` (``../examples/json_parser.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_lark_grammar.py` (``../examples/lark_grammar.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_standalone_json_parser_main.py` (``../examples/standalone/json_parser_main.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_examples_turtle_dsl.py` (``../examples/turtle_dsl.py``)
     - 00:00.000
     - 0.0
